#[derive(Yo)]
{
// Attributes available to this derive:
#[yo]
}
Write a type’s shape, its document encoding and its indexes.
See the module docs for what the attributes mean.
#[derive(Yo)]
{
// Attributes available to this derive:
#[yo]
}
Write a type’s shape, its document encoding and its indexes.
See the module docs for what the attributes mean.